Index: include/gpu/GrGpuResource.h |
diff --git a/include/gpu/GrGpuResource.h b/include/gpu/GrGpuResource.h |
index 8e983d89c57b45c36b89fed88e60c5a1c64dfc8a..baffd9ec8343bf04f9c716558003ddbf06b302ec 100644 |
--- a/include/gpu/GrGpuResource.h |
+++ b/include/gpu/GrGpuResource.h |
@@ -207,13 +207,20 @@ public: |
const SkData* getCustomData() const { return fData.get(); } |
/** |
* Internal-only helper class used for cache manipulations of the reosurce. |
*/ |
class CacheAccess; |
inline CacheAccess cacheAccess(); |
inline const CacheAccess cacheAccess() const; |
/** |
+ * Internal-only helper class used for manipulations of the resource by internal code. |
+ */ |
+ class ResourcePriv; |
+ inline ResourcePriv resourcePriv(); |
+ inline const ResourcePriv resourcePriv() const; |
+ |
+ /** |
* Removes references to objects in the underlying 3D API without freeing them. |
* Called by CacheAccess. |
* In general this method should not be called outside of skia. It was |
@@ -207,13 +207,20 @@ public: |
const SkData* getCustomData() const { return fData.get(); } |
/** |
- * Internal-only helper class used for cache manipulations of the reosurce. |
+ * Internal-only helper class used for manipulations of the resource by the cache. |
*/ |
class CacheAccess; |